<?php

namespace GooglePhotosApi\Model;

use AppBundle\PicasaAPI\Picasawebdata\PicasaClient;
use SimpleXMLElement;

/**
 * The base class for elements, providing some common helpers.
 */
abstract class AbstractMedia
{
	/**
	 * Get the name of the element type.
	 *
	 * @return string
	 */
	public function type()
	{
		$className = get_class($this);
		$lastSlash = strrpos($className, '\\');

		if ($lastSlash)
		{
			$className = substr($className, $lastSlash + 1);
		}

		return strtolower($className);
	}

	/**
	 * Make an element object model from an XML <entry> tag
	 * returned by the API.
	 *
	 * @param SimpleXMLElement $entry
	 * @param array $settings
	 * @see GooglePhotosClient::setSettings()
     *
	 * @return AbstractMedia
	 */
	abstract public static function makeFromXml(SimpleXMLElement $entry,  $settings);

	/**
	 * Check if a given <entry> xml element is a video.
	 *
	 * @param SimpleXMLElement $entry
	 *
	 * @return boolean
	 */
	public static function isVideo(SimpleXMLElement $entry)
	{
		$namespaces = $entry->getNameSpaces(true);
		$media = $entry->children($namespaces['media']);
		$resources = $media->group->content;

		foreach ($resources as $resource)
		{
			$type = (string) $resource->attributes()['medium'];
			if ($type === 'video')
				return true;
		}

		return false;
	}

	/**
     * This method rewrites the url of a thumbnail given by picasa API to change the crop mode.
     * This seems to be the only way to get custom cropping on thumbnails.
     *
     * @param string $imageUrl          The url generated by picasa API
     * @param string $requestedSize     The requested size used to generate $imageUrl
     * @param string $targetMode        The target cropping mode. Can be 'h' (height), 'w' (width), 's' (smallest), or 'l' (largest)
     * @param bool $targetCrop          Should the target image be cropped (or just resized if false)
     *
     * @return string
     */
    protected static function resizeImage($imageUrl, $requestedSize, $targetMode, $targetCrop)
    {
        $search = '/s'. $requestedSize .'-c/';

        $replace = '/' . $targetMode . $requestedSize;
        if ($targetCrop)
        {
            $replace .= '-c';
        }
        $replace .= '/';

        return str_replace($search, $replace, $imageUrl);
    }
}
